"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var common = require("./image-cache-it.common");
var image_cache_it_common_1 = require("./image-cache-it.common");
var imageSrc = require("tns-core-modules/image-source");
var view_1 = require("tns-core-modules/ui/core/view");
var fs = require("tns-core-modules/file-system");
var utils = require("tns-core-modules/utils/utils");
var types = require("tns-core-modules/utils/types");
global.moduleMerge(common, exports);
var ImageCacheIt = (function (_super) {
    __extends(ImageCacheIt, _super);
    function ImageCacheIt() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImageCacheIt.prototype.createNativeView = function () {
        var nativeView = UIImageView.new();
        nativeView.contentMode = 1;
        nativeView.userInteractionEnabled = true;
        nativeView.clipsToBounds = true;
        return nativeView;
    };
    ImageCacheIt.prototype.onMeasure = function (widthMeasureSpec, heightMeasureSpec) {
        var nativeView = this.nativeView;
        if (nativeView) {
            var width = view_1.layout.getMeasureSpecSize(widthMeasureSpec);
            var height = view_1.layout.getMeasureSpecSize(heightMeasureSpec);
            this.setMeasuredDimension(width, height);
        }
    };
    ImageCacheIt.prototype._loadImage = function (src) {
        var _this = this;
        if (!types.isNullOrUndefined(src)) {
            if (types.isString(src) && src.startsWith('http')) {
                this.isLoading = true;
                var context = {};
                this.nativeView.sd_setImageWithURLPlaceholderImageOptionsContextProgressCompleted(src, this.placeHolder
                    ? imageSrc.fromFileOrResource(this.placeHolder).ios
                    : null, 0, context, function (p1, p2, p3) {
                }, function (p1, p2, p3, p4) {
                    _this.isLoading = false;
                    if (p2 && _this.errorHolder) {
                        var source = imageSrc.fromFileOrResource(_this.errorHolder);
                        _this.nativeView.image = source ? source.ios : null;
                        _this.setAspect(_this.stretch);
                    }
                });
            }
            else if (typeof src === 'string' &&
                (src.startsWith('/') || src.startsWith('file'))) {
                var source = imageSrc.fromFileOrResource(src);
                this.nativeView.image = source ? source.ios : null;
                this.setAspect(this.stretch);
            }
            else if (typeof src === 'string' &&
                src.startsWith('~')) {
                var path = fs.knownFolders.currentApp().path;
                var file = fs.path.join(path, src.replace('~', ''));
                var source = imageSrc.fromFileOrResource(file);
                this.nativeView.image = source ? source.ios : null;
                this.setAspect(this.stretch);
            }
            else if (typeof src === 'string' && src.startsWith('res://')) {
                this.nativeView.image = UIImage.imageNamed(src.replace('res://', ''));
                this.setAspect(this.stretch);
            }
            else if (types.isObject(src) && src.ios) {
                this.nativeView.image = src.ios;
                this.setAspect(this.stretch);
            }
            else if (types.isObject(src) && src instanceof UIImage) {
                this.nativeView.image = src;
                this.setAspect(this.src);
            }
        }
    };
    ImageCacheIt.prototype.initNativeView = function () {
        _super.prototype.initNativeView.call(this);
        this._loadImage(this.src);
    };
    ImageCacheIt.prototype[common.srcProperty.getDefault] = function () {
        return undefined;
    };
    ImageCacheIt.prototype[common.srcProperty.setNative] = function (src) {
        this._loadImage(src);
    };
    ImageCacheIt.prototype[common.resizeProperty.setNative] = function (resize) {
        if (!this.nativeView)
            return resize;
        if (this.resize &&
            this.resize.split(',').length > 1) {
            this.nativeView.frame.size.width = parseInt(this.resize.split(' ')[0]);
            this.nativeView.frame.size.height = parseInt(this.resize.split(' ')[1]);
        }
        return resize;
    };
    ImageCacheIt.prototype.setAspect = function (value) {
        if (!this.nativeView)
            return value;
        switch (value) {
            case 'aspectFit':
                this.nativeView.contentMode = 1;
                break;
            case 'aspectFill':
                this.nativeView.contentMode = 2;
                break;
            case 'fill':
                this.nativeView.contentMode = 0;
                break;
            case 'none':
            default:
                this.nativeView.contentMode = 9;
                break;
        }
        return value;
    };
    ImageCacheIt.prototype[common.stretchProperty.getDefault] = function () {
        return 'aspectFit';
    };
    ImageCacheIt.prototype[common.stretchProperty.setNative] = function (value) {
        this.setAspect(value);
    };
    ImageCacheIt.prototype[common.filterProperty.setNative] = function (filter) {
    };
    ImageCacheIt.getItem = function (src) {
        return new Promise(function (resolve, reject) {
            var manager = utils.ios.getter(SDWebImageManager, SDWebImageManager.sharedManager);
            if (manager) {
                if (src && src.indexOf('http') > -1) {
                    var url = NSURL.alloc().initWithString(src);
                    manager.loadImageWithURLOptionsProgressCompleted(url, SDWebImageOptions.scaleDownLargeImages, function (receivedSize, expectedSize, path) {
                    }, function (image, data, error, type, finished, completedUrl) {
                        if (image === null && error !== null && data === null) {
                            reject(error.localizedDescription);
                        }
                        else if (finished && completedUrl != null) {
                            if (type == SDImageCacheType.disk) {
                                var key = manager.cacheKeyForURL(completedUrl);
                                var source = manager.imageCache.defaultCachePathForKey(key);
                                resolve(source);
                            }
                            else {
                                var sharedCache = utils.ios.getter(SDImageCache, SDImageCache.sharedImageCache);
                                sharedCache.storeImageForKeyCompletion(image, completedUrl.absoluteString, function () {
                                    var key = manager.cacheKeyForURL(completedUrl);
                                    var source = manager.imageCache.defaultCachePathForKey(key);
                                    resolve(source);
                                });
                            }
                        }
                        else {
                            reject();
                        }
                    });
                }
            }
            else {
                reject();
            }
        });
    };
    ImageCacheIt.deleteItem = function (src) {
        return new Promise(function (resolve, reject) {
            var manager = utils.ios.getter(SDWebImageManager, SDWebImageManager.sharedManager);
            if (manager) {
                manager.imageCache.removeImageForKeyFromDiskWithCompletion(src, true, function () {
                    resolve();
                });
            }
            else {
                reject();
            }
        });
    };
    ImageCacheIt.fetchItem = function (src) {
        return new Promise(function (resolve, reject) {
            var manager = utils.ios.getter(SDWebImageManager, SDWebImageManager.sharedManager);
            if (manager) {
                if (src && src.indexOf('http') > -1) {
                    var nativeSrc = NSURL.alloc().initWithString(src);
                    manager.loadImageWithURLOptionsProgressCompleted(nativeSrc, SDWebImageOptions.scaleDownLargeImages, function (receivedSize, expectedSize, path) {
                    }, function (image, data, error, type, finished, completedUrl) {
                        if (image === null && error !== null && data === null) {
                            reject(error.localizedDescription);
                        }
                        else if (finished && completedUrl != null) {
                            if (type === SDImageCacheType.disk) {
                                var key = manager.cacheKeyForURL(completedUrl);
                                var source = manager.imageCache.defaultCachePathForKey(key);
                                resolve(source);
                            }
                            else {
                                var sharedCache = utils.ios.getter(SDImageCache, SDImageCache.sharedImageCache);
                                sharedCache.storeImageForKeyCompletion(image, completedUrl.absoluteString, function () {
                                    var key = manager.cacheKeyForURL(completedUrl);
                                    var source = manager.imageCache.defaultCachePathForKey(key);
                                    resolve(source);
                                });
                            }
                        }
                    });
                }
            }
            else {
                reject();
            }
        });
    };
    return ImageCacheIt;
}(image_cache_it_common_1.ImageCacheItBase));
exports.ImageCacheIt = ImageCacheIt;
//# sourceMappingURL=image-cache-it.ios.js.map